==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Všechny obrázky</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemáte oprávnění k zobrazení obrázku</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Zachyceno</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim expozice</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Expoziční program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Expoziční čas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdálenost</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Největší clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Režim měření</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyvážení bílé</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompenzace blesku</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektivu</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barevný prostor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Značka</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Velikost 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Přizpůsobit oknu</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Rozpoznat text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Zobrazit okno navigace</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrýt okno navigace</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>day</source>
        <translation>den</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Napište nový název</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenalezeny žádné soubory s obrázky</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Soubor s obrázkem nenalezen.</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.39.orig.tar.xz: image-editor-1.0.39/libimageviewer/translations/libimageviewer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Všechny obrázky</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemáte oprávnění k zobrazení obrázku</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Zachyceno</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim expozice</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Expoziční program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Expoziční čas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdálenost</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Největší clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Režim měření</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyvážení bílé</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Náhrada za blesk</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektivu</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barevný prostor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Značka</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Velikost 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Přizpůsobit oknu</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Rozpoznat text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Zobrazit okno navigace</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrýt okno navigace</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>day</source>
        <translation>den</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Napište nový název</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenalezeny žádné soubory s obrázky</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Soubor s obrázkem nenalezen.</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Nemáte oprávnění k zobrazení souboru</translation>
    </message>
</context>
</TS>
